@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 # PuLP : Python LP Modeler
-# Version 1.20
+# Version 1.4.2
 
 # Copyright (c) 2002-2005, Jean-Sebastien Roy (js@jeannot.org)
 # Modifications Copyright (c) 2007- Stuart Anthony Mitchell (s.mitchell@auckland.ac.nz)
@@ -208,24 +208,21 @@ class LpElement(object):
 
   
 class LpVariable(LpElement):
-    """A LP variable"""
+    """
+    This class models an LP Variable with the specified associated parameters
+        
+    :param name: The name of the variable used in the output .lp file
+    :param lowbound: The lower bound on this variable's range. 
+        Default is negative infinity
+    :param upBound: The upper bound on this variable's range. 
+        Default is positive infinity
+    :param cat: The category this variable is in, Integer, Binary or 
+        Continuous(default)
+    :param e: Used for column based modelling: relates to the variable's 
+        existence in the objective function and constraints
+    """
     def __init__(self, name, lowBound = None, upBound = None,
                   cat = LpContinuous, e = None):
-        """
-        Creates an LP variable
-        
-        This function creates an LP Variable with the specified associated parameters
-            
-        Inputs:
-            - name: The name of the variable used in the output .lp file
-            - lowbound -- Optional: The lower bound on this variable's range. Default is negative infinity
-            - upBound -- Optional: The upper bound on this variable's range. Default is positive infinity
-            - cat -- Optional: The category this variable is in, Integer, Binary or Continuous(default)
-            - e -- Optional: Used for column based modelling: relates to the variable's existence in the objective function and constraints
-                     
-        Returns:
-            - An LP variable
-        """
         LpElement.__init__(self,name)
         self.lowBound = lowBound
         self.upBound = upBound
@@ -245,33 +242,42 @@ class LpVariable(LpElement):
         self.expression = e
         self.addVariableToConstraints(e)
 
-    def matrix(self, name, indexs, lowBound = None, upBound = None, cat = 0, indexStart = []):
+    def matrix(self, name, indexs, lowBound = None, upBound = None, cat = 0,
+            indexStart = []):
         if not isinstance(indexs, tuple): indexs = (indexs,)
         if "%" not in name: name += "_%s" * len(indexs)
 
         index = indexs[0]
         indexs = indexs[1:]
         if len(indexs) == 0:
-            return [LpVariable(name % tuple(indexStart + [i]), lowBound, upBound, cat) for i in index]
+            return [LpVariable(name % tuple(indexStart + [i]),
+                                            lowBound, upBound, cat)
+                        for i in index]
         else:
-            return [LpVariable.matrix(name, indexs, lowBound, upBound, cat, indexStart + [i]) for i in index]
+            return [LpVariable.matrix(name, indexs, lowBound,
+                                        upBound, cat, indexStart + [i])
+                       for i in index]
     matrix = classmethod(matrix)
 
-    def dicts(self, name, indexs, lowBound = None, upBound = None, cat = 0, indexStart = []):
+    def dicts(self, name, indexs, lowBound = None, upBound = None, cat = 0, 
+        indexStart = []):
         """
         Creates a dictionary of LP variables
         
-        This function creates a dictionary of LP Variables with the specified associated parameters.
+        This function creates a dictionary of LP Variables with the specified 
+            associated parameters.
             
-        Inputs:
-            - name: The prefix to the name of each LP variable created
-            - indexs: A list of strings of the keys to the dictionary of LP variables, and the main part of the variable name itself
-            - lowbound -- Optional: The lower bound on these variables' range. Default is negative infinity
-            - upBound -- Optional: The upper bound on these variables' range. Default is positive infinity
-            - cat -- Optional: The category these variables are in, Integer or Continuous(default)
+        :param name: The prefix to the name of each LP variable created
+        :param indexs: A list of strings of the keys to the dictionary of LP
+            variables, and the main part of the variable name itself
+        :param lowbound: The lower bound on these variables' range. Default is
+            negative infinity
+        :param upBound: The upper bound on these variables' range. Default is
+            positive infinity
+        :param cat: The category these variables are in, Integer or
+            Continuous(default)
                                  
-        Returns:
-            - A dictionary of LP Variables
+        :return: A dictionary of LP Variables
         """
         if not isinstance(indexs, tuple): indexs = (indexs,)
         if "%" not in name: name += "_%s" * len(indexs)
@@ -1652,12 +1658,13 @@ class FractionElasticSubProblem(FixedElasticSubProblem):
     Contains the subproblem generated by converting an Fraction constraint 
     numerator/(numerator+complement) = b
     into an elastic constraint
-    @param constraint: The LpFractionConstraint that the elastic constraint is 
-    based on
-    @param penalty: penalty applied for violation (+ve or -ve) of the constraints
-    @param proportionFreeBound: the proportional bound (+ve and -ve) on 
+    
+    :param constraint: The LpFractionConstraint that the elastic constraint is 
+        based on
+    :param penalty: penalty applied for violation (+ve or -ve) of the constraints
+    :param proportionFreeBound: the proportional bound (+ve and -ve) on 
         constraint violation that is free from penalty
-    @param proportionFreeBoundList: the proportional bound on 
+    :param proportionFreeBoundList: the proportional bound on 
         constraint violation that is free from penalty, expressed as a list 
         where [-ve, +ve]
     """
@@ -1737,14 +1744,13 @@ class LpVariableDict(dict):
             self[key] = LpVariable(name % key, lowBound, upBound, cat)
             return self[key]
 
-# Utility fonctions
+# Utility functions
 
 def lpSum(vector):
     """
     Calculate the sum of a list of linear expressions
     
-    Inputs:
-         - vector -- A list of linear expressions
+    :param vector: A list of linear expressions
     """
     return LpAffineExpression().addInPlace(vector)
 
@@ -1780,12 +1786,13 @@ def combination(orgset, k = None):
     returns an iterator that lists the combinations of orgset of 
     length k
     
-    @param orgset: the list to be iterated
-    @param k: the cardinality of the subsets
+    :param orgset: the list to be iterated
+    :param k: the cardinality of the subsets
     
-    @return: an iterator of the subsets
+    :return: an iterator of the subsets
     
     example:
+    
     >>> c = combination([1,2,3,4],2)
     >>> for s in c:
     ...     print s
@@ -1821,12 +1828,13 @@ def permutation(orgset, k = None):
     returns an iterator that lists the permutations of orgset of 
     length k
     
-    @param orgset: the list to be iterated
-    @param k: the cardinality of the subsets
+    :param orgset: the list to be iterated
+    :param k: the cardinality of the subsets
     
-    @return: an iterator of the subsets
+    :return: an iterator of the subsets
     
     example:
+    
     >>> c = permutation([1,2,3,4],2)
     >>> for s in c:
     ...     print s
@@ -1866,12 +1874,14 @@ def __permutation(orgset, k):
 def allpermutations(orgset,k):
     """
     returns all purmutations of orgset with up to k items
-    @param orgset: the list to be iterated
-    @param k: the maxcardinality of the subsets
     
-    @return: an iterator of the subsets
+    :param orgset: the list to be iterated
+    :param k: the maxcardinality of the subsets
+    
+    :return: an iterator of the subsets
     
     example:
+    
     >>> c = allpermutations([1,2,3,4],2)
     >>> for s in c:
     ...     print s
@@ -1897,12 +1907,14 @@ def allpermutations(orgset,k):
 def allcombinations(orgset,k):
     """
     returns all purmutations of orgset with up to k items
-    @param orgset: the list to be iterated
-    @param k: the maxcardinality of the subsets
     
-    @return: an iterator of the subsets
+    :param orgset: the list to be iterated
+    :param k: the maxcardinality of the subsets
+    
+    :return: an iterator of the subsets
     
     example:
+    
     >>> c = allcombinations([1,2,3,4],2)
     >>> for s in c:
     ...     print s
@@ -1950,12 +1962,10 @@ def splitDict(Data):
     """
     Split a dictionary with lists as the data, into smaller dictionaries
     
-    Inputs:
-        - Data: A dictionary with lists as the values
+    :param Data: A dictionary with lists as the values
         
-    Returns:
-        - A tuple of dictionaries each containing the data separately, 
-          with the same dictionary keys
+    :return: A tuple of dictionaries each containing the data separately, 
+            with the same dictionary keys
     """
     # find the maximum number of items in the dictionary
     maxitems = max([len(values) for values in Data.values()])
@@ -2075,12 +2085,15 @@ def pulpTest012(solver):
     prob += -y+z == 7, "c3"
     prob += w >= 0, "c4"
     print "\t Testing unbounded continuous LP solution"
-    if solver.__class__ in [COINMP_DLL, GUROBI]:
+    if solver.__class__ in [COINMP_DLL, GUROBI, CPLEX_CMD,]:
             # COINMP_DLL Does not report unbounded problems, correctly
              pulpTestCheck(prob, solver, [LpStatusInfeasible])
     elif solver.__class__ is GLPK_CMD:
         # GLPK_CMD Does not report unbounded problems, correctly
          pulpTestCheck(prob, solver, [LpStatusUndefined])
+    elif solver.__class__ in [CPLEX_DLL,]:
+        # GLPK_CMD Does not report unbounded problems, correctly
+         pulpTestCheck(prob, solver, [LpStatusNotSolved])
     else:
         pulpTestCheck(prob, solver, [LpStatusUnbounded])
 
@@ -2154,11 +2167,11 @@ def pulpTest060(solver):
     prob += x+y <= 5.2, "c1"
     prob += x+z >= 10.3, "c2"
     prob += -y+z == 7.4, "c3"
-    if solver.__class__ in [ GLPK_CMD]:
+    if solver.__class__ in [GLPK_CMD, COIN_CMD]:
         # GLPK_CMD returns InfeasibleOrUnbounded
         print "\t Testing an integer infeasible problem"
         pulpTestCheck(prob, solver, [LpStatusInfeasible, LpStatusUndefined])
-    elif solver.__class__ in [COINMP_DLL, COIN_CMD]:
+    elif solver.__class__ in [COINMP_DLL]:
         #Currently there is an error in COINMP for problems where
         #presolve elimiates too many variables
         print "\t Testing an integer infeasible problem (Error to be fixed)"
@@ -2370,12 +2383,15 @@ def pulpTest123(solver):
     prob.extend((w >= -1).makeElasticSubProblem(penalty = 0.9))
     print "\t Testing elastic constraints (penalty unbounded)"
     prob.writeLP('debug.lp')
-    if solver.__class__ in [COINMP_DLL, GUROBI]:
+    if solver.__class__ in [COINMP_DLL, GUROBI, CPLEX_CMD]:
         # COINMP_DLL Does not report unbounded problems, correctly
          pulpTestCheck(prob, solver, [LpStatusInfeasible])
     elif solver.__class__ is GLPK_CMD:
         # GLPK_CMD Does not report unbounded problems, correctly
          pulpTestCheck(prob, solver, [LpStatusUndefined])
+    elif solver.__class__ in [CPLEX_DLL]:
+        # GLPK_CMD Does not report unbounded problems, correctly
+         pulpTestCheck(prob, solver, [LpStatusNotSolved])
     else:
         pulpTestCheck(prob, solver, [LpStatusUnbounded])
 
@@ -2398,8 +2414,8 @@ def pulpTestSolver(solver):
         t(solver(msg=0))
 
 def pulpTestAll():
-    solvers = [#CPLEX_DLL, 
-               #CPLEX_CMD,
+    solvers = [CPLEX_DLL, 
+               CPLEX_CMD,
                COIN_CMD, 
                COINMP_DLL,
                GLPK_CMD,
@@ -2412,7 +2428,7 @@ def pulpTestAll():
             try:
                 pulpTestSolver(s)
                 print "* Solver", s, "passed."
-            except (),e:
+            except Exception, e:
                 print e
                 print "* Solver", s, "failed."
         else:
