@@ -1,5 +1,5 @@
 # PuLP : Python LP Modeler
-# Version 1.20
+# Version 1.4.2
 
 # Copyright (c) 2002-2005, Jean-Sebastien Roy (js@jeannot.org)
 # Modifications Copyright (c) 2007- Stuart Anthony Mitchell (s.mitchell@auckland.ac.nz)
@@ -992,9 +992,10 @@ class COIN_CMD(LpSolver_CMD):
         values = {}
         for v in vs:
             values[v.name] = 0.0
-        cbcStatus = {'Optimal':LpStatusOptimal, 
-                    'Infeasible':LpStatusInfeasible,
-                    'Unbounded':LpStatusUnbounded}
+        cbcStatus = {'Optimal': LpStatusOptimal,
+                    'Infeasible': LpStatusInfeasible,
+                    'Unbounded': LpStatusUnbounded,
+                    'Stopped': LpStatusNotSolved}
         f = file(filename)
         statusstr = f.readline().split()[0]
         status = cbcStatus.get(statusstr, LpStatusUndefined)
